/*
 * The SmartWeb Framework
 * Copyright (C) 2004-2006
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * For further informations on the SmartWeb Framework please visit
 *
 *                        http://smartweb.sourceforge.net
 */
package net.smartlab.web.test;

import java.io.FileNotFoundException;
import java.net.URL;
import java.util.Properties;

import net.smartlab.web.BusinessObjectFactory;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.hibernate.SessionFactory;
import org.hibernate.cfg.Configuration;

/**
 * TODO documentation
 * 
 * @author rlogiacco
 */
public class BusinessObjectFactoryTestSupport implements net.smartlab.web.config.FactoryConfigurationStrategy {
	/**
	 * Provides logging for the test cases.
	 */
	private Log logger = LogFactory.getLog(this.getClass());
	
	/**
	 * Stores configured session factory
	 */
	private SessionFactory factory;

	/**
	 * The url from which configuration file will be loaded
	 */
	private URL configuration;


	/**
	 * TODO documentation
	 * 
	 * @param businessObjectFactoryTestCase
	 */
	public BusinessObjectFactoryTestSupport(URL configuration) {
		this.configuration = configuration;
	}

	/**
	 * @see net.smartlab.web.config.FactoryConfigurationStrategy#getSessionFactory(net.smartlab.web.BusinessObjectFactory)
	 */
	public SessionFactory getSessionFactory(BusinessObjectFactory bof) {
		try {
			factory = (SessionFactory)BusinessObjectFactoryTestCase.factories.get(configuration.toString());
			if (factory == null) {
				logger.debug("internal session factory cache lookup failed");
				Configuration config = new Configuration().configure(configuration);
				try {
					Properties props = new Properties();
					props.load(Object.class.getResourceAsStream("/hibernate.properties"));
					config.addProperties(props);
				} catch (FileNotFoundException fne) {
					logger.trace("hibernate.properties file not found");
				}
				factory = config.buildSessionFactory();
				BusinessObjectFactoryTestCase.factories.put(configuration.toString(), factory);
			}
		} catch (Exception e) {
			throw new RuntimeException(e);
		}
		return factory;
	}
}