/*
 * The SmartWeb Framework
 * Copyright (C) 2004-2006
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * For further informations on the SmartWeb Framework please visit
 *
 *                        http://smartweb.sourceforge.net
 */
package net.smartlab.web.test;

import junit.framework.Assert;
import junit.framework.AssertionFailedError;
import net.smartlab.web.Enumeration;


/**
 * Utility class to test <code>net.smartlab.web.Enumeration</code> implementations
 * 
 * @author gcontartese
 * @author rlogiacco
 */
public class EnumerationAssert extends Assert {

	/**
	 * Avoid a new instance
	 */
	private EnumerationAssert() {
	}

	/**
	 * @deprecated replaced by {@link #assertEquals(net.smartlab.web.Enumeration, int)}
	 * @see #assertEquals(net.smartlab.web.Enumeration, int)
	 */
	public static void assertDecode(Enumeration expected, int actual) {
		EnumerationAssert.assertEquals(expected, actual);
	}

	/**
	 * Asserts that after a decode Enumeration are equals. If it isn't it throws
	 * an AssertionFailedError with the standard message.
	 * 
	 * @param expected the not-null expected result
	 * @param actual the value used to decode an enumeration
	 */
	public static void assertEquals(Enumeration expected, int actual) {
		EnumerationAssert.assertEquals(expected, actual, null);
	}

	/**
	 * Asserts that after a decode Enumeration are equals. If it isn't it throws
	 * an AssertionFailedError with the given message.
	 * 
	 * @param expected the not-null expected result
	 * @param actual the value used to decode an enumeration
	 */
	public static void assertEquals(Enumeration expected, int actual, String message) {
		if (expected != null) {
			Enumeration decoded = expected.decode(actual);
			assertEquals(expected, decoded, message);
		} else {
			throw new AssertionFailedError("No enumeration implementation has been provided for decoding");
		}
	}

	/**
	 * Asserts that two Enumeration are equals. If it isn't it throws an
	 * AssertionFailedError with the standard message.
	 * 
	 * @param expected the expected result
	 * @param actual the actual value
	 */
	public static void assertEquals(Enumeration expected, Enumeration actual) {
		EnumerationAssert.assertEquals(expected, actual, null);
	}

	/**
	 * Asserts that two Enumeration are equals. If it isn't it throws an
	 * AssertionFailedError with the given message.
	 * 
	 * @param expected the expected result
	 * @param actual the actual value
	 */
	public static void assertEquals(Enumeration expected, Enumeration actual, String message) {
		if ((actual == null && expected != null) || (actual != null && !actual.equals(expected))) {
			if (message == null) {
				StringBuffer sb = new StringBuffer();
				sb.append("expected: <");
				sb.append(expected == null ? "null" : expected.getId() + ", " + expected.getDisplay());
				sb.append("> but was <");
				sb.append(actual == null ? "null" : actual.getId() + ", " + actual.getDisplay());
				sb.append(">");
				throw new AssertionFailedError(sb.toString());
			} else {
				throw new AssertionFailedError(message);
			}
		}
	}
}
